@@ -39,6 +39,14 @@ public:
      * is first shown, its items are laid out correctly.
      */
     void showEvent(QShowEvent *event) override;
+    /*
+     * @short Open a dialogue when data is available.
+     * When there is data in the Alternative Translation View
+     * but the view is hidden, inform the user that displaying
+     * the view might be useful, and allow the user to show it.
+     * @author Finley Watson
+     */
+    void conditionallyPromptToDisplay();
 
 public Q_SLOTS:
     void slotNewEntryDisplayed(const DocPosition &);
@@ -47,7 +55,6 @@ public Q_SLOTS:
     void addAlternateTranslation(int entry, const QString &);
 
 private Q_SLOTS:
-    // void contextMenu(const QPoint & pos);
     void process();
     void initLater();
     void slotUseSuggestion(int);
@@ -62,12 +69,12 @@ private:
     bool event(QEvent *event) override;
 
 private:
-    TM::DynamicItemHeightQListWidget *m_atm_entries_list{nullptr};
+    TM::DynamicItemHeightQListWidget *m_entriesList{nullptr};
     Catalog *m_catalog;
     QString m_normTitle;
     QString m_hasInfoTitle;
     bool m_hasInfo{};
-    bool m_everShown{};
+    bool m_everCheckedAboutPromptingToShow{};
     DocPos m_entry;
     DocPos m_prevEntry;
 
