@@ -3,6 +3,7 @@
 
   SPDX-FileCopyrightText: 2007-2014 Nick Shaforostoff <shafff@ukr.net>
   SPDX-FileCopyrightText: 2018-2019 Simon Depiets <sdepiets@gmail.com>
+  SPDX-FileCopyrightText: 2025 Finley Watson <fin-w@tutanota.com>
 
   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
@@ -15,6 +16,7 @@
 #include <config.h>
 #endif
 
+#include "config-lokalize.h"
 #include "lokalizetabpagebase.h"
 #include "pos.h"
 
@@ -82,8 +84,7 @@ public:
  *
  * This class can be called a dispatcher for one message catalog.
  *
- * It is accessible via Lokalize.currentEditor() from kross scripts and via
- * '/ThisIsWhatYouWant/Editor/# : org.kde.Lokalize.Editor' from qdbusviewer
+ * It is accessible via '/ThisIsWhatYouWant/Editor/# : org.kde.Lokalize.Editor' from qdbusviewer
  *
  * @author Nick Shaforostoff <shafff@ukr.net>
  */
@@ -99,10 +100,9 @@ public:
     ~EditorTab() override;
 
     // interface for LokalizeMainWindow
-    void hideDocks() override;
-    void showDocks() override;
     QString currentFilePath() override;
     void setFullPathShown(bool);
+    void updateStatusBarContents() override;
 
 public Q_SLOTS:
     void setProperFocus();
@@ -113,7 +113,9 @@ public:
     {
         return (KXMLGUIClient *)this;
     }
+#if HAVE_DBUS
     QString dbusObjectPath();
+#endif
     int dbusId()
     {
         return m_dbusId;
@@ -310,7 +312,6 @@ private Q_SLOTS:
 private:
     void setupAccel();
     void setupActions();
-    void setupStatusBar();
 
     void findNext(const DocPosition &startingPos);
     void replaceNext(const DocPosition &);
