@@ -3,6 +3,7 @@
 
   SPDX-FileCopyrightText: 2007-2012 Nick Shaforostoff <shafff@ukr.net>
   SPDX-FileCopyrightText: 2018-2019 Simon Depiets <sdepiets@gmail.com>
+  SPDX-FileCopyrightText: 2025 Finley Watson <fin-w@tutanota.com>
 
   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
@@ -10,6 +11,7 @@
 #ifndef FILESEARCHTAB_H
 #define FILESEARCHTAB_H
 
+#include "config-lokalize.h"
 #include "lokalizetabpagebase.h"
 #include "pos.h"
 #include "qaview.h"
@@ -51,21 +53,18 @@ public:
     explicit FileSearchTab(QWidget *parent);
     ~FileSearchTab() override;
 
-    void hideDocks() override
-    {
-    }
-    void showDocks() override
-    {
-    }
     KXMLGUIClient *guiClient() override
     {
         return (KXMLGUIClient *)this;
     }
+#if HAVE_DBUS
     QString dbusObjectPath();
+#endif
     int dbusId()
     {
         return m_dbusId;
     }
+    void updateStatusBarContents() override;
 
 public Q_SLOTS:
     void copySourceToClipboard();
