@@ -3,6 +3,7 @@
 
   SPDX-FileCopyrightText: 2008-2014 Nick Shaforostoff <shafff@ukr.net>
   SPDX-FileCopyrightText: 2018-2019 Simon Depiets <sdepiets@gmail.com>
+  SPDX-FileCopyrightText: 2025 Finley Watson <fin-w@tutanota.com>
 
   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
@@ -10,23 +11,26 @@
 #ifndef LOKALIZEMAINWINDOW_H
 #define LOKALIZEMAINWINDOW_H
 
+#include "config-lokalize.h"
 #include "filesearchtab.h"
 #include "lokalizetabpagebase.h"
 #include "pos.h"
 #include "projecttab.h"
+#include "statusbar.h"
 #include "tmtab.h"
 
 #include <KConfigGroup>
 #include <KXMLGUIClient>
 #include <KXmlGuiWindow>
 
-#include <QDBusObjectPath>
 #include <QMap>
 #include <QPointer>
 #include <QStackedLayout>
 #include <QTabWidget>
+#include <QTimer>
 #include <QUrl>
 #include <QWidget>
+#include <qnamespace.h>
 #include <qtmetamacros.h>
 
 class QLabel;
@@ -45,8 +49,7 @@ class TMTab;
  * Sets up actions, and maintains their connection with active subwindow via ActionProxy
  * As such, it handles the menus, toolbars, and status bars.
  *
- * It is known as Lokalize in kross scripts and as
- * '/ThisIsWhatYouWant : org.kde.Lokalize.MainWindow' in qdbusviewer
+ * It is known as '/ThisIsWhatYouWant : org.kde.Lokalize.MainWindow' in qdbusviewer
  *
  * @author Nick Shaforostoff <shafff@ukr.net>
  */
@@ -60,9 +63,8 @@ public:
     LokalizeMainWindow();
     ~LokalizeMainWindow() override;
 
-    StatusBarProxy mainWindowStatusBarItems;
-
 protected:
+    void saveCurrentEditorState();
     void saveProjectState(KConfigGroup &);
     void saveProperties(KConfigGroup &stateGroup) override;
     /*
@@ -72,7 +74,9 @@ protected:
      */
     bool queryClose() override;
     void readProperties(const KConfigGroup &stateGroup) override;
+#if HAVE_DBUS
     void registerDBusAdaptor();
+#endif
     void setupActions();
 
 private Q_SLOTS:
@@ -198,13 +202,14 @@ Q_SIGNALS:
     Q_SCRIPTABLE void editorActivated();
 
 private:
+    bool eventFilter(QObject *object, QEvent *event) override;
     int previousActiveTabIndex;
     KXMLGUIClient *m_activeTabPageKeyboardShortcuts{};
     QActionGroup *m_editorActions{};
     QActionGroup *m_managerActions{};
     KRecentFilesAction *m_openRecentFileAction{};
     KRecentFilesAction *m_openRecentProjectAction{};
-    QVector<QLabel *> m_statusBarLabels;
+    QMetaObject::Connection activeStatusBarConnection;
 
     /*
      * @short The state of the editor that was last in focus.
@@ -212,7 +217,7 @@ private:
      * (dock widget layout etc.) and when a project is closed
      * this is the editor state saved to disk.
      */
-    QByteArray m_lastEditorState;
+    QByteArray m_editorStateOfAllOpenEditors;
 
     typedef QMap<QString, EditorTab *> FileToEditor;
     FileToEditor m_fileToEditor;
@@ -232,6 +237,20 @@ private:
     TM::TMTab *m_translationMemoryTab{};
     FileSearchTab *m_fileSearchTab{};
     bool m_translationMemoryTabIsVisible;
+    LokalizeStatusBar *m_statusBar{};
+
+    int m_statusBarCurrentIndex;
+    int m_statusBarTotalCount;
+    int m_statusBarFuzzyNotReadyCount;
+    int m_statusBarUntranslatedCount;
+    int m_statusBarReadyCount;
+    int m_statusBarProgressPercentage;
+    QLabel *m_statusBarCurrentLabel;
+    QLabel *m_statusBarTotalLabel;
+    QLabel *m_statusBarFuzzyNotReadyLabel;
+    QLabel *m_statusBarUntranslatedLabel;
+    QLabel *m_statusBarReadyLabel;
+    QProgressBar *m_statusBarProgressBar;
 };
 
 class DelayedFileOpener : public QObject
