@@ -8,6 +8,7 @@
 */
 
 #include "catalogstring.h"
+#include "config-lokalize.h"
 #include "editortab.h"
 #include "jobs.h"
 #include "lokalize_debug.h"
@@ -20,6 +21,10 @@
 #include "stemming.h"
 #include "version.h"
 
+#if HAVE_DBUS
+#include <KDBusService>
+#endif
+
 #include <QApplication>
 #include <QCommandLineOption>
 #include <QCommandLineParser>
@@ -37,9 +42,8 @@
 
 #include <KAboutData>
 #include <KCrash>
-#include <KDBusService>
-#include <KLocalizedString>
 #include <KIconTheme>
+#include <KLocalizedString>
 
 int main(int argc, char **argv)
 {
@@ -65,7 +69,6 @@ int main(int argc, char **argv)
     KStyleManager::initStyle();
 #endif
 
-
     KLocalizedString::setApplicationDomain("lokalize");
     QApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("lokalize")));
     QCommandLineParser parser;
@@ -109,7 +112,9 @@ int main(int argc, char **argv)
     qCDebug(LOKALIZE_LOG) << qRegisterMetaType<CatalogString>();
     qAddPostRoutine(&cleanupSpellers);
 
+#if HAVE_DBUS
     const KDBusService dbusService(KDBusService::Multiple);
+#endif
 
     // see if we are starting with session management
     if (app.isSessionRestored())
