@@ -17,6 +17,7 @@
 #include "project.h"
 
 #include <QApplication>
+#include <QLatin1String>
 #include <QStringBuilder>
 #include <QTextEdit>
 
@@ -30,22 +31,10 @@ SyntaxHighlighter::SyntaxHighlighter(QTextEdit *parent)
 {
     highlightingRules.reserve(NUM_OF_RULES);
     HighlightingRule rule;
-    // rule.format.setFontItalic(true);
-    //     tagFormat.setForeground(tagBrush.brush(QApplication::palette()));
     setAutomatic(false);
 
     tagFormat.setForeground(tagBrush.brush(QApplication::palette()));
 
-    // QTextCharFormat format;
-    // tagFormat.setForeground(Qt::darkBlue);
-    //     if (!docbook) //support multiline tags
-    //     {
-    //         rule.format = tagFormat;
-    //         rule.pattern = QRegExp("<.+>");
-    //         rule.pattern.setMinimal(true);
-    //         highlightingRules.append(rule);
-    //     }
-
     // entity
     rule.format.setForeground(tagBrush.brush(QApplication::palette()));
     rule.pattern = QRegularExpression(QStringLiteral("(&[A-Za-z_:][A-Za-z0-9_\\.:-]*;)"));
@@ -106,17 +95,6 @@ void SyntaxHighlighter::settingsChanged()
     }
 }
 
-/*
-void SyntaxHighlighter::setFuzzyState(bool fuzzy)
-{
-    return;
-    int i=NUM_OF_RULES;
-    while(--i>=0)
-        highlightingRules[i].format.setFontItalic(fuzzy);
-
-    tagFormat.setFontItalic(fuzzy);
-}*/
-
 void SyntaxHighlighter::highlightBlock(const QString &text)
 {
     int currentBlockState = STATE_NORMAL;
@@ -125,24 +103,23 @@ void SyntaxHighlighter::highlightBlock(const QString &text)
     setFormat(0, text.length(), f);
 
     tagFormat.setFontItalic(!m_approved);
-    // if (fromDocbook)
-    {
-        int startIndex = STATE_NORMAL;
-        if (previousBlockState() != STATE_TAG)
-            startIndex = text.indexOf(QLatin1Char('<'));
+    int startIndex = STATE_NORMAL;
+    // Probably matches the start of a HTML tag (opening or closing).
+    auto startOfHtmlTag = QRegularExpression(QLatin1String("</?[a-zA-Z]"));
+    if (previousBlockState() != STATE_TAG)
+        startIndex = text.indexOf(startOfHtmlTag, 0);
 
-        while (startIndex >= 0) {
-            int endIndex = text.indexOf(QLatin1Char('>'), startIndex);
-            int commentLength;
-            if (endIndex == -1) {
-                currentBlockState = STATE_TAG;
-                commentLength = text.length() - startIndex;
-            } else {
-                commentLength = endIndex - startIndex + 1 /*+ commentEndExpression.matchedLength()*/;
-            }
-            setFormat(startIndex, commentLength, tagFormat);
-            startIndex = text.indexOf(QLatin1Char('<'), startIndex + commentLength);
+    while (startIndex >= 0) {
+        int endIndex = text.indexOf(QLatin1Char('>'), startIndex);
+        int commentLength;
+        if (endIndex == -1) {
+            currentBlockState = STATE_TAG;
+            commentLength = text.length() - startIndex;
+        } else {
+            commentLength = endIndex - startIndex + 1;
         }
+        setFormat(startIndex, commentLength, tagFormat);
+        startIndex = text.indexOf(startOfHtmlTag, startIndex + commentLength);
     }
 
     for (const HighlightingRule &rule : std::as_const(highlightingRules)) {
@@ -162,29 +139,6 @@ void SyntaxHighlighter::highlightBlock(const QString &text)
     setCurrentBlockState(currentBlockState);
 }
 
-#if 0
-void SyntaxHighlighter::setFormatRetainingUnderlines(int start, int count, QTextCharFormat f)
-{
-    QVector<bool> underLines(count);
-    for (int i = 0; i < count; ++i)
-        underLines[i] = format(start + i).fontUnderline();
-
-    setFormat(start, count, f);
-
-    f.setFontUnderline(true);
-    int prevStart = -1;
-    bool isPrevUnderLined = false;
-    for (int i = 0; i < count; ++i) {
-        if (!underLines.at(i) && prevStart != -1)
-            setFormat(start + isPrevUnderLined, i - prevStart, f);
-        else if (underLines.at(i) && !isPrevUnderLined)
-            prevStart = i;
-
-        isPrevUnderLined = underLines.at(i);
-    }
-}
-#endif
-
 void SyntaxHighlighter::setMisspelled(int start, int count)
 {
     const Project &project = *Project::instance();
